@@ -1,5 +1,5 @@
 package Starch::Plugin::AlwaysLoad;
-$Starch::Plugin::AlwaysLoad::VERSION = '0.04';
+$Starch::Plugin::AlwaysLoad::VERSION = '0.05';
 =head1 NAME
 
 Starch::Plugin::AlwaysLoad - Always retrieve state data.
@@ -28,13 +28,13 @@ with qw(
     Starch::Plugin::ForState
 );
 
-sub BUILD {
+after BUILD => sub{
     my ($self) = @_;
 
     $self->data();
 
     return;
-}
+};
 
 1;
 __END__
