@@ -1,5 +1,5 @@
 package Starch::Plugin::LogStoreExceptions;
-$Starch::Plugin::LogStoreExceptions::VERSION = '0.04';
+$Starch::Plugin::LogStoreExceptions::VERSION = '0.05';
 =head1 NAME
 
 Starch::Plugin::LogStoreExceptions - Turn Starch store exceptions into log messages.
@@ -47,7 +47,7 @@ foreach my $method (qw( set get remove )) {
         catch {
             $self->log->errorf(
                 'Starch store %s errored when %s was called: %s',
-                ref($self), $method, $_,
+                $self->short_store_class_name(), $method, $_,
             );
             return {
                 $self->manager->no_store_state_key() => 1,
