@@ -1,5 +1,5 @@
 package Starch::Store;
-$Starch::Store::VERSION = '0.04';
+$Starch::Store::VERSION = '0.05';
 =head1 NAME
 
 Starch::Store - Base role for Starch stores.
@@ -40,6 +40,9 @@ requires qw(
     remove
 );
 
+# Declare BUILD so roles can apply method modifiers to it.
+sub BUILD { }
+
 around set => sub{
     my ($orig, $self, $id, $keys, $data, $expires) = @_;
 
