@@ -1,5 +1,5 @@
 package Starch::Store::Layered;
-$Starch::Store::Layered::VERSION = '0.04';
+$Starch::Store::Layered::VERSION = '0.05';
 =head1 NAME
 
 Starch::Store::Layered - Layer multiple Starch stores.
@@ -60,7 +60,7 @@ with qw(
     Starch::Store
 );
 
-sub BUILD {
+after BUILD => sub{
     my ($self) = @_;
 
     # Load these up as early as possible.
@@ -68,7 +68,7 @@ sub BUILD {
     $self->inner();
 
     return;
-}
+};
 
 =head1 REQUIRED ARGUMENTS
 
